==> ask_sdk_model-1.18.1-py2.py3-none-any.whl: ask_sdk_model/services/monetization/in_skill_product_transactions_response.py <==
# coding: utf-8

#
# Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file
# except in compliance with the License. A copy of the License is located at
#
# http://aws.amazon.com/apache2.0/
#
# or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
# the specific language governing permissions and limitations under the License.
#

import pprint
import re  # noqa: F401
import six
import typing
from enum import Enum


if typing.TYPE_CHECKING:
    from typing import Dict, List, Optional, Union
    from datetime import datetime
    from ask_sdk_model.services.monetization.transactions import Transactions
    from ask_sdk_model.services.monetization.metadata import Metadata


class InSkillProductTransactionsResponse(object):
    """

    :param results: List of transactions of in skill products purchases
    :type results: (optional) list[ask_sdk_model.services.monetization.transactions.Transactions]
    :param metadata: 
    :type metadata: (optional) ask_sdk_model.services.monetization.metadata.Metadata

    """
    deserialized_types = {
        'results': 'list[ask_sdk_model.services.monetization.transactions.Transactions]',
        'metadata': 'ask_sdk_model.services.monetization.metadata.Metadata'
    }  # type: Dict

    attribute_map = {
        'results': 'results',
        'metadata': 'metadata'
    }  # type: Dict

    def __init__(self, results=None, metadata=None):
        # type: (Optional[List[Transactions]], Optional[Metadata]) -> None
        """

        :param results: List of transactions of in skill products purchases
        :type results: (optional) list[ask_sdk_model.services.monetization.transactions.Transactions]
        :param metadata: 
        :type metadata: (optional) ask_sdk_model.services.monetization.metadata.Metadata
        """
        self.__discriminator_value = None  # type: str

        self.results = results
        self.metadata = metadata

    def to_dict(self):
        # type: () -> Dict[str, object]
        """Returns the model properties as a dict"""
        result = {}  # type: Dict

        for attr, _ in six.iteritems(self.deserialized_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else
                    x.value if isinstance(x, Enum) else x,
                    value
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else
                    (item[0], item[1].value)
                    if isinstance(item[1], Enum) else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        # type: () -> str
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        # type: () -> str
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        # type: (object) -> bool
        """Returns true if both objects are equal"""
        if not isinstance(other, InSkillProductTransactionsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        # type: (object) -> bool
        """Returns true if both objects are not equal"""
        return not self == other

==> ask_sdk_model-1.72.0-py2.py3-none-any.whl: ask_sdk_model/services/monetization/in_skill_product_transactions_response.py <==
# coding: utf-8

#
# Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file
# except in compliance with the License. A copy of the License is located at
#
# http://aws.amazon.com/apache2.0/
#
# or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
# the specific language governing permissions and limitations under the License.
#

import pprint
import re  # noqa: F401
import six
import typing
from enum import Enum


if typing.TYPE_CHECKING:
    from typing import Dict, List, Optional, Union, Any
    from datetime import datetime
    from ask_sdk_model.services.monetization.metadata import Metadata as Metadata_a873d209
    from ask_sdk_model.services.monetization.transactions import Transactions as Transactions_c92d5d49


class InSkillProductTransactionsResponse(object):
    """

    :param results: List of transactions of in skill products purchases
    :type results: (optional) list[ask_sdk_model.services.monetization.transactions.Transactions]
    :param metadata: 
    :type metadata: (optional) ask_sdk_model.services.monetization.metadata.Metadata

    """
    deserialized_types = {
        'results': 'list[ask_sdk_model.services.monetization.transactions.Transactions]',
        'metadata': 'ask_sdk_model.services.monetization.metadata.Metadata'
    }  # type: Dict

    attribute_map = {
        'results': 'results',
        'metadata': 'metadata'
    }  # type: Dict
    supports_multiple_types = False

    def __init__(self, results=None, metadata=None):
        # type: (Optional[List[Transactions_c92d5d49]], Optional[Metadata_a873d209]) -> None
        """

        :param results: List of transactions of in skill products purchases
        :type results: (optional) list[ask_sdk_model.services.monetization.transactions.Transactions]
        :param metadata: 
        :type metadata: (optional) ask_sdk_model.services.monetization.metadata.Metadata
        """
        self.__discriminator_value = None  # type: str

        self.results = results
        self.metadata = metadata

    def to_dict(self):
        # type: () -> Dict[str, object]
        """Returns the model properties as a dict"""
        result = {}  # type: Dict

        for attr, _ in six.iteritems(self.deserialized_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else
                    x.value if isinstance(x, Enum) else x,
                    value
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else
                    (item[0], item[1].value)
                    if isinstance(item[1], Enum) else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        # type: () -> str
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        # type: () -> str
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        # type: (object) -> bool
        """Returns true if both objects are equal"""
        if not isinstance(other, InSkillProductTransactionsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        # type: (object) -> bool
        """Returns true if both objects are not equal"""
        return not self == other
